/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'sr', {
	border: 'Величина оквира',
	caption: 'Наслов табеле',
	cell: {
		menu: 'Ћелија',
		insertBefore: 'Убаци лево',
		insertAfter: 'Убаци десно',
		deleteCell: 'Обриши ћелије',
		merge: 'Спој ћелије',
		mergeRight: 'Спој ћелије на десно',
		mergeDown: 'Спој ћелије на доле',
		splitHorizontal: 'Раздвој ћелије водоравно',
		splitVertical: 'Раздвој ћелије усправно',
		title: 'Карактеристика ћелија',
		cellType: 'Тип ћелија',
		rowSpan: 'Спој уздужно',
		colSpan: 'Спој водоравно',
		wordWrap: 'Брисање дугачких редова',
		hAlign: 'Равнање водоравно',
		vAlign: 'Равнање усправно',
		alignBaseline: 'Базна линија',
		bgColor: 'Боја позадине',
		borderColor: 'Боја оквира',
		data: 'Податак',
		header: 'Наслов',
		columnHeader: 'Заглавље колоне',
		rowHeader: 'Заглавље реда',
		yes: 'Да',
		no: 'Не',
		invalidWidth: 'У поље ширина можете уписати само бројеве.',
		invalidHeight: 'У поље висина можете уписати само бројеве.',
		invalidRowSpan: 'У поље спој усправно можете уписати само бројеве.',
		invalidColSpan: 'У поље спој водоравно можете уписати само бројеве.',
		chooseColor: 'Изабери'
	},
	cellPad: 'Размак ћелија',
	cellSpace: 'Ћелијски простор',
	column: {
		menu: 'Колона',
		insertBefore: 'Убаци лево',
		insertAfter: 'Убаци десно',
		deleteColumn: 'Обриши колоне'
	},
	columns: 'Kолона',
	deleteTable: 'Обриши таблу',
	headers: 'Поглавља',
	headersBoth: 'Оба',
	headersColumn: 'Прва колона',
	headersNone: 'Нема',
	headersRow: 'Први ред',
	heightUnit: 'Јединица висине',
	invalidBorder: 'Величина ивице треба да буде цифра.',
	invalidCellPadding: 'Пуњење ћелије треба да буде позитивна цифра.',
	invalidCellSpacing: 'Размак ћелије треба да буде позитивна цифра.',
	invalidCols: 'Број колона треба да буде цифра већа од 0.',
	invalidHeight: 'Висина табеле треба да буде цифра.',
	invalidRows: 'Број реда треба да буде цифра већа од 0.',
	invalidWidth: 'Ширина табеле треба да буде цифра.',
	menu: 'Карактеристике табеле',
	row: {
		menu: 'Ред',
		insertBefore: 'Убаци изнад',
		insertAfter: 'Убаци испод',
		deleteRow: 'Обриши редове'
	},
	rows: 'Редови',
	summary: 'Oпис',
	title: 'Карактеристике табеле',
	toolbar: 'Табела',
	widthPc: 'процената',
	widthPx: 'пиксела',
	widthUnit: 'јединица ширине'
} );
